==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/bean/AccountBaseEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 基本补贴表
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_account_base")
public class AccountBaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pk_psndoc")
    private String pkPsndoc; // 人员主键
    @TableField(value="psncode")
    private String psncode; // 人员编码
    @TableField(value="pk_certifreg")
    private Long pkCertifreg; // 证件
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 证件类别
    @TableField(value="djmonth")
    private String djmonth; // 登记日期
    @TableField(value="expire_time")
    private String expireTime; // 证件失效时间
    @TableField(value="bttype")
    private String bttype; // 补贴类别（1-一次性奖励额 2-基本补贴额）
    @TableField(value="lastjfdate")
    private String lastjfdate; // 最后计费月份(基本补贴额，初次登记该字段=登记日期)
    @TableField(value="isstop")
    private String isstop; // 是否停止计费
    @TableField(value="stop_time")
    private String stopTime; // 停止计费时间
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="ts")
    private Date ts; // 时间戳
    
    
    

    public String getPkPsndoc() {
        return pkPsndoc;
    }

    public void setPkPsndoc(String pkPsndoc) {
        this.pkPsndoc = pkPsndoc;
    }
    public String getPsncode() {
        return psncode;
    }

    public void setPsncode(String psncode) {
        this.psncode = psncode;
    }
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public String getDjmonth() {
        return djmonth;
    }

    public void setDjmonth(String djmonth) {
        this.djmonth = djmonth;
    }
    public String getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(String expireTime) {
        this.expireTime = expireTime;
    }
    public String getBttype() {
        return bttype;
    }

    public void setBttype(String bttype) {
        this.bttype = bttype;
    }
    public String getLastjfdate() {
        return lastjfdate;
    }

    public void setLastjfdate(String lastjfdate) {
        this.lastjfdate = lastjfdate;
    }
    public String getIsstop() {
        return isstop;
    }

    public void setIsstop(String isstop) {
        this.isstop = isstop;
    }
    public String getStopTime() {
        return stopTime;
    }

    public void setStopTime(String stopTime) {
        this.stopTime = stopTime;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220614.031901-51-sources.jar: com/ejianc/certify/bean/AccountBaseEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 基本补贴表
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_account_base")
public class AccountBaseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pk_psndoc")
    private Long pkPsndoc; // 人员主键
    @TableField(value="psncode")
    private String psncode; // 人员编码
    @TableField(value="pk_certifreg")
    private Long pkCertifreg; // 证件
    @TableField(value="pk_certiftype")
    private Long pkCertiftype; // 证件类别
    @TableField(value="djmonth")
    private String djmonth; // 登记日期
    @TableField(value="expire_time")
    private String expireTime; // 证件失效时间
    @TableField(value="bttype")
    private String bttype; // 补贴类别（1-一次性奖励额 2-基本补贴额）
    @TableField(value="lastjfdate")
    private String lastjfdate; // 最后计费月份(基本补贴额，初次登记该字段=登记日期)
    @TableField(value="isstop")
    private String isstop; // 是否停止计费
    @TableField(value="stop_time")
    private String stopTime; // 停止计费时间
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="ts")
    private Date ts; // 时间戳
    
    
    

    public Long getPkPsndoc() {
        return pkPsndoc;
    }

    public void setPkPsndoc(Long pkPsndoc) {
        this.pkPsndoc = pkPsndoc;
    }
    public String getPsncode() {
        return psncode;
    }

    public void setPsncode(String psncode) {
        this.psncode = psncode;
    }
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public String getDjmonth() {
        return djmonth;
    }

    public void setDjmonth(String djmonth) {
        this.djmonth = djmonth;
    }
    public String getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(String expireTime) {
        this.expireTime = expireTime;
    }
    public String getBttype() {
        return bttype;
    }

    public void setBttype(String bttype) {
        this.bttype = bttype;
    }
    public String getLastjfdate() {
        return lastjfdate;
    }

    public void setLastjfdate(String lastjfdate) {
        this.lastjfdate = lastjfdate;
    }
    public String getIsstop() {
        return isstop;
    }

    public void setIsstop(String isstop) {
        this.isstop = isstop;
    }
    public String getStopTime() {
        return stopTime;
    }

    public void setStopTime(String stopTime) {
        this.stopTime = stopTime;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}
